/*******************************************************************
 * Fritz Fun                                                       *
 * Created by Louis Lagendijk                                      *
 * All parts are distributed under the terms of GPLv2. See COPYING *
 *******************************************************************/

/**
 * \file menu.c
 * \brief Wrapper for he menu system (trayicon and menubar)
 */

#include <ffgtk.h>
#include <trayicon.h>
#include <limits.h>
#include <osdep/osdep.h>

static int nOpenWindows = 0;

/**
 * \brief mark windos as open
 * \param window to be marked open
 */
void markWindowOpen( int nType ) {
	nOpenWindows = nOpenWindows | nType;
	Debug( KERN_DEBUG, "nOpenWindows is now: %d\n", nOpenWindows );
}

/**
 * \brief Mark window as closed
 * \param window to be marked closed
 */
void markWindowClosed( int nType) {
	nOpenWindows = nOpenWindows & ( INT_MAX ^ nType  );
	Debug( KERN_DEBUG, "nOpenWindows is now: %d\n", nOpenWindows );
}

/**
 * \brief  Check if windows is open
 * \param window to checked
 * \return status of window
 */
bool windowIsOpen( int nType ) {
	return ( ( nOpenWindows & nType ) != 0 );
}

/**
 * \brief Get map of open windows
 * \return map of open windows
 */
int getOpenWindows( void ) {
	return nOpenWindows;
}

/**
 * \brief Initialize menu system, create menu bar and tray icon andi start tooltip thread
 */
void menuInit( void ) {
	trayIconInit();
#ifdef __MACOSX__
	menuBarInit();
#endif
}

/**
 * \brief recreate app menu
 */
void menuRecreateAppMenu( void ) {
	trayIconRecreateAppMenu();
#ifdef __MACOSX__
	menuBarRecreateAppMenu();
#endif
}

/**
 * \brief set program icon on trayicon
 * \param icvon type to be set
 */
void menuSetIconType( int nType ) {
	trayIconSetIconType(nType);
}

/**
 *  \brief get menu/trayicon widget
 * \return trayicon widget
 */
GtkStatusIcon *menuGetIcon( void ) {
	return getTrayIcon();
}
